@@ -12,7 +12,6 @@ def reporthook(downloaded, total_size):
 
 
 class BaseReader(object):
-
     def unpack(self, format, data):
         '''
         解压文件
@@ -37,8 +36,7 @@ class BaseReader(object):
 
 
 class BaseFinancial:
-
-    def __init__(self, mode="http"):
+    def __init__(self, mode="content"):
         self.mode = mode
 
     def fetch_and_parse(self,
@@ -115,7 +113,15 @@ class BaseFinancial:
             "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_0) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/76.0.3809.100 Safari/537.36"
         )
 
-        res = urlopen(request)
+        print(url)
+        try:
+            res = urlopen(request)
+        except Exception as e:
+            raise e
+        else:
+            pass
+        finally:
+            pass
 
         if res.getheader('Content-Length') is not None:
             total_size = int(res.getheader('Content-Length').strip())
