@@ -3,8 +3,8 @@ import logging
 import math
 
 import pandas
-from .contrib.pytdx.exhq import TdxExHq_API
-from .contrib.pytdx.hq import TdxHq_API
+from pytdx.exhq import TdxExHq_API
+from pytdx.hq import TdxHq_API
 from tqdm import tqdm
 
 from mootdx import config
@@ -17,7 +17,6 @@ config.setup()
 
 
 class Quotes(object):
-
     @staticmethod
     def factory(market='std', **kwargs):
         '''
@@ -204,13 +203,14 @@ class StdQuotes(object):
         :param date: 日期
         :return: pd.dataFrame or None
         '''
+        # get_history_transaction_data(self, market, code, start, count, date):
         with self.client.connect(*self.bestip):
             market = get_stock_market(symbol, string=False)
             result = self.client.get_history_transaction_data(market=market,
                                                               code=symbol,
                                                               start=start,
                                                               count=offset,
-                                                              date=date)
+                                                              date=int(date))
 
             return to_data(result)
 
@@ -303,7 +303,7 @@ class StdQuotes(object):
         '''
         with self.client.connect(*self.bestip):
             result = self.client.get_k_data(symbol, begin, end)
-            return to_data(result)
+            return result
 
     def index(self,
               symbol='000001',
@@ -426,8 +426,7 @@ class ExtQuotes(object):
             result = []
 
             for page in tqdm(range(0, pages)):
-                result += self.client.get_instrument_info(
-                    page * 100, (page + 1) * 100)
+                result += self.client.get_instrument_info(page * 100, 100)
 
             return to_data(result)
 
@@ -466,13 +465,14 @@ class ExtQuotes(object):
         :param date:
         :return:
         '''
+        # get_history_minute_time_data(self, market, code, date):
         market, symbol = self.validate(market, symbol)
         with self.client.connect(*self.bestip):
             result = self.client.get_history_minute_time_data(
                 market, symbol, date)
             return to_data(result)
 
-    def bars(self, frequency='', market='', symbol='', start='', offset=0):
+    def bars(self, frequency='', market='', symbol='', start=0, offset=100):
         '''
         查询k线数据
         参数： K线周期， 市场ID， 证券代码，起始位置， 数量
@@ -486,11 +486,12 @@ class ExtQuotes(object):
         '''
         market, symbol = self.validate(market, symbol)
         with self.client.connect(*self.bestip):
-            result = self.client.get_instrument_bars(frequency=frequency,
+            result = self.client.get_instrument_bars(category=frequency,
                                                      market=market,
                                                      code=symbol,
                                                      start=start,
                                                      count=offset)
+
             return to_data(result)
 
     def transaction(self, market=None, symbol='', start=0, offset=1800):
@@ -531,7 +532,7 @@ class ExtQuotes(object):
         with self.client.connect(*self.bestip):
             result = self.client.get_history_transaction_data(market=market,
                                                               code=symbol,
-                                                              date=date,
+                                                              date=int(date),
                                                               start=start,
                                                               count=offset)
             return to_data(result)
