@@ -4,16 +4,14 @@ import os
 
 from mootdx.consts import TYPE_GROUP
 from mootdx.utils import get_stock_market
-from .contrib.pytdx.reader import (BlockReader, CustomerBlockReader,
-                                   TdxDailyBarReader, TdxExHqDailyBarReader,
-                                   TdxLCMinBarReader)
+from pytdx.reader import (BlockReader, CustomerBlockReader, TdxDailyBarReader,
+                          TdxExHqDailyBarReader, TdxLCMinBarReader)
 
 logger = logging.getLogger(__name__)
 
 
 # 股票市场
 class Reader(object):
-
     @staticmethod
     def factory(market='std', **kwargs):
         '''
@@ -76,7 +74,6 @@ class ReaderBase(object):
 
 class StdReader(ReaderBase):
     """股票市场"""
-
     def daily(self, symbol=None):
         '''
         获取日线数据
@@ -126,16 +123,16 @@ class StdReader(ReaderBase):
         if custom:
             reader = CustomerBlockReader()
             vipdoc = os.path.join(self.tdxdir, 'T0002', 'blocknew',
-                                  '{}'.format(symbol))
+                                  f'{symbol}.dat')
         else:
             reader = BlockReader()
             vipdoc = os.path.join(self.tdxdir, 'T0002', 'hq_cache',
-                                  '{}.dat'.format(symbol))
+                                  f'{symbol}.dat')
 
         fmt = TYPE_GROUP if group else None
 
         if os.path.exists(vipdoc):
-            return reader.get_df(vipdoc, format)
+            return reader.get_df(vipdoc, fmt)
         else:
             logger.error('未找到所需的文件: {}'.format(vipdoc))
 
@@ -144,7 +141,6 @@ class StdReader(ReaderBase):
 
 class ExtReader(ReaderBase):
     """扩展市场读取"""
-
     def daily(self, symbol=None):
         '''
         获取日线数据
